# [QuGrad](README.md) Change Log

## Release 1.0.1

- Bug fix in documentation generation
- Various typo corrections in the documentation

## Release 1.0.0

This is the initial release. Future changes to this release will be documented above.